FrameMetadata class

Object with the information that accompanied a Frame.

pts and dts are in stream timebase. size is in bytes.

Implementers

Constructors

FrameMetadata({int? pts, int? dts, Duration? delay, int? size})

Properties

delay ↔ Duration?
getter/setter pair
dts ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pts ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited