VideoFrameMetadata class

Object with the information that accompanied a VideoFrame.

Inheritance

Constructors

VideoFrameMetadata({int? pts, int? dts, Duration? delay, int? size, ImageFormat? imageFormat, int? width, int? height})

Properties

delay ↔ Duration?
getter/setter pairinherited
dts ↔ int?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
getter/setter pair
imageFormat ↔ ImageFormat?
getter/setter pair
pts ↔ int?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
getter/setter pairinherited
width ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited