Video class

A widget that displays video through a VidenaPlayer A progress bar for this Video is obtainable by calling getProgressBar

Inheritance

Constructors

Video({Key? key})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
player → VidenaPlayer
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → VideoState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dispose() → Future<void>
getProgressBar() → ProgressBarProvider
Creates a ProgressBarProvider that will update with the time of this Video
getSnapshot() → Future<Snapshot?>
Pauses the video and returns a Snapshot.
nFramesBackward(int n) → void
nFramesForward(int n) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(String file, {bool startOnPause = false}) → Future<void>
pause() → void
play() → void
saveSnapshotTo(String path) → Future<void>
Pauses the video and saves a snapshot in the provided path. The snapshot will be saved as a png.
seekPrecise(Duration duration) → void
This will seek to the exact frame indicated by duration, or the frame before, instead of seeking to a keyframe like seekTime does.
seekTime(Duration duration) → void
setPlaybackSpeed(double speed) → void
takeSnapshot() → Future<void>
Pauses the video and saves a snapshot in the desired location.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
togglePause() → void
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited